@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Depak;
 
 our $DATE = '2015-07-04'; # DATE
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 use 5.010001;
 use strict;
@@ -9,6 +9,7 @@ use warnings;
 
 use App::lcpan::Call qw(call_lcpan_script);
 use Data::Dmp;
+use Dist::Zilla::File::InMemory;
 use File::Slurper qw(read_binary write_binary);
 use File::Temp qw(tempfile);
 use File::Which;
@@ -21,6 +22,7 @@ with (
     'Dist::Zilla::Role::FileFinderUser' => {
         default_finders => [':ExecFiles', ':InstallModules'],
     },
+    'Dist::Zilla::Role::FileGatherer',
     'Dist::Zilla::Role::FileMunger',
 );
 
@@ -109,8 +111,12 @@ sub munge_script {
         $self->{_mods}{$_} = 0;
     }
 
-    $file->content($content);
-    $file->encoding('bytes');
+    # re-add the file instead of changing the content, so we can re-set the
+    # encoding to 'bytes'
+    my $newfile = Dist::Zilla::File::InMemory->new(
+        encoding=>'bytes', name=>$file->{name}, content => $content);
+    $self->zilla->prune_file($file);
+    $self->add_file($newfile);
 }
 
 sub munge_module {
@@ -148,9 +154,11 @@ sub munge_module {
     }
 }
 
+sub gather_files {}
+
 __PACKAGE__->meta->make_immutable;
 1;
-# ABSTRACT: (DEPRECATED) Pack dependencies onto scripts during build using 'depak'
+# ABSTRACT: Pack dependencies onto scripts during build using 'depak'
 
 __END__
 
@@ -160,11 +168,11 @@ __END__
 
 =head1 NAME
 
-Dist::Zilla::Plugin::Depak - (DEPRECATED) Pack dependencies onto scripts during build using 'depak'
+Dist::Zilla::Plugin::Depak - Pack dependencies onto scripts during build using 'depak'
 
 =head1 VERSION
 
-This document describes version 0.07 of Dist::Zilla::Plugin::Depak (from Perl distribution Dist-Zilla-Plugin-Depak), released on 2015-07-04.
+This document describes version 0.08 of Dist::Zilla::Plugin::Depak (from Perl distribution Dist-Zilla-Plugin-Depak), released on 2015-07-04.
 
 =head1 SYNOPSIS
 
